# Preamble

Name: nfsv4-daemons
Version: 0.9
Release: 2
Serial: 30718

#
# This release supports Kerberos 5 mutual authentication, integrity,
# and privacy
#
# TODO: 
#   +  gssd client and server in separate subpackages
#   +  integrate these programs into nfs-utils and initscripts RPMs
#

Summary: User-land daemons for NFSv4
License: MIT, freely distributable.
Distribution: NFSv4

Vendor: Center for Information Technology Integration, University of Michigan
Packager: Trond Myklebust <trond.myklebust@fys.uio.no>

URL: http://www.citi.umich.edu/projects/nfsv4/
Group: System Environment/Daemons

#
# The kerberos distribution is required because the gss daemons
# require a modified version of certain kerberos libraries.  This
# modification will eventually appear in the MIT kerberos
# distribution.  At that point we may significantly simplify this
# RPM.
#
Source0: krb5_1.2.7.orig.tar.gz
Source2: gssd-2003-10-12.tar.gz
Source3: idmapd-2003-10-12.tar.gz
Source4: startup.tar.gz


## gssd patches 0-999


## idmapd patches 1000-1999
Patch1000: idmap-man.patch
Patch1010: idmap-conf.patch
Patch1020: idmap-domain.patch
Patch1030: idmap-pipefs.patch


## krb patches 5000-5999
Patch5100: krb5-mechglue-enable.patch
Patch5110: krb5-mechglue-andros.patch
Patch5120: krb5-sucks.patch


BuildRoot: %{_tmppath}/%{name}-root
#Requires: usermode
#Conflicts: kernel < 2.4.18-18
Prereq: grep, info, sh-utils, /sbin/install-info
BuildPrereq: bison, e2fsprogs-devel, flex, gzip, texinfo, tar, tcl

BuildRequires: sed
BuildRequires: ncurses-devel
BuildRequires: libtermcap-devel
BuildRequires: zlib-devel
BuildRequires: m4
BuildRequires: gcc

%description
The nfsv4-daemons package contains user-level daemons that are
required to run NFSv4 clients and servers on Linux.

This package contains two user-level daemons for the Linux kernel
RPCSEC_GSS implementation, one for the client, and for the server.
Each daemon implements the full RPCSEC_GSS (RFC 2203) specification.

This package also contains a user-level daemon to map names to UIDs
and GIDs, which can require communication with external network
databases (NIS, LDAP, etc.).


%prep

#
# unpack the kerberos distribution
#
%setup -q -c %{name}-%{version}

cd krb5-1.2.7/src
# enable compilation of the mechglue subdirectory
%patch5100 -E -p1
# add andy's mechglue changes
%patch5110 -E -p1
# Misc fixups
%patch5120 -E -p2

cd ../doc
gzip *.ps

#
# unpack the gssd distribution
#
%setup -q -c %{name}-%{version} -T -D -b 2
cd gssd

#
# unpack the idmapd distribution
#
%setup -q -c %{name}-%{version} -T -D -b 3
cd idmapper
%patch1000 -E -p1
%patch1010 -E -p1
%patch1020 -E -p1
%patch1030 -E -p1

#
# unpack the startup scripts
#
%setup -q -c %{name}-%{version} -T -D -b 4
cd init.d


%build

# Build idmapd.
cd idmapper
automake --add-missing --foreign
./configure \
	--prefix=${RPM_BUILD_ROOT} \
	--exec-prefix=${RPM_BUILD_ROOT}/usr \
	--bindir=${RPM_BUILD_ROOT}/usr/sbin \
	--sysconfdir=${RPM_BUILD_ROOT}/etc \
	--mandir=${RPM_BUILD_ROOT}/usr/share/man \
	--program-prefix=rpc.
make -s
cd ..

# Build the kerberos distribution.  This goop was lifted from
# the Red Hat krb5 source rpm, and adjusted accordingly.

rm -rf /tmp/kerberos

cd krb5-1.2.7/src
libtoolize --copy --force
cp config.{guess,sub} config/

# If any of our patches alter a configure.in file, this
# next step will rebuild the necessary configure scripts.
cd util/autoconf
./configure
make
cd ../..
util/reconf --force

DEFINES="-D_FILE_OFFSET_BITS=64" ; export DEFINES
./configure \
	--with-cc=%{__cc} \
	--with-ccopts="$RPM_OPT_FLAGS $ARCH_OPT_FLAGS $DEFINES -fPIC" \
	--enable-static \
	--disable-shared \
	--prefix=/tmp/kerberos \
	--exec-prefix=/tmp/kerberos \
	--localstatedir=%{_var}/kerberos \
	--without-krb4 \
	--with-netlib=-lresolv \
	--with-tcl=%{_prefix} \
	--enable-dns

# Now build it.  Override the CC_LINK variable to exclude the rpath.
# NB: This doesn't have to build all of Kerberos right now, because gssd
#     only uses the gssapi mech glue stuff at the moment.  eventually it
#     will use krb5's spkm and rpc libraries too.
make -s CC_LINK='$(CC) $(PROG_LIBPATH)'

# Install this build in /tmp/kerberos.
make install
cd ../..

# Build the gss daemons.
cd gssd

./configure \
	--with-cc=%{__cc} \
	--with-ccopts="$RPM_OPT_FLAGS $ARCH_OPT_FLAGS $DEFINES" \
	--prefix=${RPM_BUILD_ROOT} \
	--exec-prefix=${RPM_BUILD_ROOT}/usr \
	--bindir=${RPM_BUILD_ROOT}/usr/sbin \
	--mandir=${RPM_BUILD_ROOT}/usr/share/man \
	--with-krb5=/tmp/kerberos

make -s all
cd ..


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

mkdir -p ${RPM_BUILD_ROOT}/usr/sbin
mkdir -p ${RPM_BUILD_ROOT}/etc/rc.d/init.d
mkdir -p ${RPM_BUILD_ROOT}/usr/share/man/man8

# gssd install
cd gssd
make install
cd ..

# idmapper for NFSv4 is idmapper/idmapd
cd idmapper
make install
cd ..

# boot scripts
install -p init.d/rpcidmapd   ${RPM_BUILD_ROOT}/etc/rc.d/init.d/rpcidmapd
install -p init.d/rpcgssd     ${RPM_BUILD_ROOT}/etc/rc.d/init.d/rpcgssd
install -p init.d/rpcsvcgssd  ${RPM_BUILD_ROOT}/etc/rc.d/init.d/rpcsvcgssd


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}



%post
#
# execute chkconfig commands to enable idmapd and gssd
# to be started during the next reboot
#
chkconfig --add rpcgssd
chkconfig --add rpcsvcgssd
chkconfig --add rpcidmapd

#
# add rpc_pipefs to /etc/fstab
#
FSTAB="none    /var/lib/rpc_pipes        rpc_pipefs            defaults    0 0"

RPC_PIPEFS=`grep -v '^#' /etc/fstab | awk '{ if ($3 ~ /^rpc_pipefs$/ ) print $2}'`
if [ ! -n "$RPC_PIPEFS" ]; then
	cp /etc/fstab /etc/fstab.clnt
	echo $FSTAB >> /etc/fstab
	if [ ! -d /var/lib/rpc_pipes ]; then
		mkdir /var/lib/rpc_pipes
	fi
fi

#
# add rpc_svc_pipefs to /etc/fstab
#
#FSTAB="none    /var/lib/rpc_svc_pipes    rpc_svc_gss_pipefs    defaults    0 0"
#RPC_SVC_PIPEFS=`grep -v '^#' /etc/fstab | awk '{ if ($3 ~ /^rpc_svc_gss_pipefs$/ ) print $2}'`
#if [ ! -n "$RPC_SVC_PIPEFS" ]; then
#	cp /etc/fstab /etc/fstab.svc
#	echo $FSTAB >> /etc/fstab
#	if [ ! -d /var/lib/rpc_svc_pipes ]; then
#		mkdir /var/lib/rpc_svc_pipes
#	fi
#fi

#
# add appropriate module aliases
#
echo "alias nfs4 nfs" >> /etc/modules.conf
echo "alias rpc_pipefs sunrpc" >> /etc/modules.conf
echo "alias rpc_svc_gss_pipefs sunrpc" >> /etc/modules.conf


%preun
#
# unmount all NFSv4 mounts; without the idmapper and gssd, all
# NFSv4 activity will hang
#
umount -fa -t nfs4

#
# kill any running gssd and idmapd daemons
#
if [ -x /usr/bin/killall ]; then
	/usr/bin/killall --wait rpc.gssd
	/usr/bin/killall --wait rpc.idmapd
fi

#
# execute a couple of chkconfig commands to disable idmapd and gssd
# startup and shutdown
#
chkconfig --del rpcgssd
chkconfig --del rpcsvcgssd
chkconfig --del rpcidmapd


%files
%attr(755, root, root) /usr/sbin/rpc.idmapd
%attr(755, root, root) /usr/sbin/rpc.gssd
%attr(755, root, root) /usr/sbin/rpc.svcgssd

%attr(755, root, root) /etc/rc.d/init.d/rpcidmapd
%attr(755, root, root) /etc/rc.d/init.d/rpcgssd
%attr(755, root, root) /etc/rc.d/init.d/rpcsvcgssd

%attr(644, root, root) /etc/idmapd.conf
%config /etc/idmapd.conf

%attr(644, root, root) /usr/share/man/man8/rpc.gssd.8.gz
%attr(644, root, root) /usr/share/man/man8/rpc.svcgssd.8.gz
%attr(644, root, root) /usr/share/man/man8/rpc.idmapd.8.gz


%changelog
* Fri Jul 18 2003 Chuck Lever <cel@netapp.com>
- Release Two

* Wed Jul 02 2003 Chuck Lever <cel@netapp.com>
- default gssd behavior is now not to require srvtab on the client
- default imapd behavior is to use a bogus domain name, and force
  admins to adjust it to an appropriate value during installation

* Fri May 02 2003 Chuck Lever <cel@netapp.com>
- fix serial number
- latest versions of gssd (04/09) and idmap (1.4)

* Fri Feb 21 2003 Chuck Lever <cel@netapp.com>
- latest versions of gssd and idmap

* Fri Feb 07 2003 Chuck Lever <cel@netapp.com>
- post-installation scripts
- idmap 1.3
- adjust configure scripts again

* Thu Jan 30 2003 Chuck Lever <cel@netapp.com>
- move up to Kerberos 5 1.2.7

* Fri Jan 24 2003 Chuck Lever <cel@netapp.com>
- Created this RPM
